@@ -1,3 +1,40 @@
+.__global__ <-
+c("d.units", "day.name", "day.abb", "wdConst", "hblue", "hred", 
+"hgreen")
+.DoCount <-
+function(y, x, wts) {
+  
+  btree <- function(n) {
+    ranks <- rep(0L, n)
+    yet.to.do <- 1:n
+    depth <- floor(logb(n, 2))
+    start <- as.integer(2^depth)
+    lastrow.length <- 1 + n - start
+    indx <- seq(1L, by = 2L, length = lastrow.length)
+    ranks[yet.to.do[indx]] <- start + 0:(length(indx) - 1L)
+    yet.to.do <- yet.to.do[-indx]
+    while (start > 1) {
+      start <- as.integer(start/2)
+      indx <- seq(1L, by = 2L, length = start)
+      ranks[yet.to.do[indx]] <- start + 0:(start - 1L)
+      yet.to.do <- yet.to.do[-indx]
+    }
+    ranks
+  }
+  
+  if(missing(wts)) wts <- rep(1, length(x))
+  
+  ord <- order(y)
+  ux <- sort(unique(x))
+  n2 <- length(ux)
+  index <- btree(n2)[match(x[ord], ux)] - 1L
+  y <- cbind(y,1)
+  res <- .Call("conc", y[ord,], as.double(wts[ord]), 
+        as.integer(index), as.integer(n2))
+  
+  return(list(pi.c = NA, pi.d = NA, C = res[1], D = res[3]))
+  
+}
 .fmt <-
 function(x, digits=3, sdigits=7, big.mark="'") {
   x <- as.numeric(x)
@@ -15,6 +52,48 @@ function(x, digits=3, sdigits=7, big.mark="'") {
     formatC(x)
   }  
 }
+.pAD <-
+function(q, n=Inf, lower.tail=TRUE, fast=TRUE) {
+  q <- as.numeric(q)
+  p <- rep(NA_real_, length(q))
+  if(any(ones <- is.infinite(q) & (q == Inf)))
+    p[ones] <- 1
+  if(any(zeroes <- (is.finite(q) & q <= 0) | (is.infinite(q) & (q == -Inf))))
+    p[zeroes] <- 0
+  ok <- is.finite(q) & (q > 0)
+  nok <- sum(ok)
+  if(nok > 0) {
+    if(is.finite(n)) {
+      z <- .C("ADprobN",
+              a       = as.double(q[ok]),
+              na      = as.integer(nok),
+              nsample = as.integer(n),
+              prob    = as.double(numeric(nok))
+      )
+      p[ok] <- z$prob
+    } else if(fast) {
+      ## fast version adinf()
+      z <- .C("ADprobApproxInf",
+              a    = as.double(q[ok]),
+              na   = as.integer(nok),
+              prob = as.double(numeric(nok))
+      )
+      p[ok] <- z$prob
+    } else {
+      ## slow, accurate version ADinf()
+      z <- .C("ADprobExactInf",
+              a    = as.double(q[ok]),
+              na   = as.integer(nok),
+              prob = as.double(numeric(nok))
+      )
+      p[ok] <- z$prob
+    }
+    
+  }
+  if(!lower.tail)
+    p <- 1 - p
+  return(p)
+}
 .PageDF <-
 structure(list(NA_real_, NA_real_, k3 = c(0.166666666666667, 
 0.333333333333333, 0, 0.333333333333333, 0.166666666666667), 
@@ -816,132 +895,131 @@ structure(list(NA_real_, NA_real_, k3 = c(0.166666666666667,
 "k6", "k7", "k8", "k9", "k10", "k11", "k12", "k13", "k14", "k15"
 ))
 .Random.seed <-
-c(403L, 32L, -1313655383L, -1044067085L, -1138018404L, 1673106914L, 
-1545747826L, 179429618L, -1651492925L, -1220951369L, 899262132L, 
-1841495577L, 1898112065L, 1166942114L, -1936696613L, -166271962L, 
--1842379283L, 137168445L, 1360831745L, -1253313093L, -1598421477L, 
-1991796589L, 177795349L, 1724057911L, -619568320L, -1460691944L, 
--1665418936L, -1046652562L, -1722394511L, -1561106020L, 233013348L, 
-1772410475L, 1957262124L, -1822719415L, 384567504L, -1188568200L, 
-1405486159L, 1187340733L, -2111393578L, -1261125866L, 1254991368L, 
-1659471545L, -1794157396L, -238629496L, 1088761454L, -511212392L, 
-1859118556L, -1490323672L, 1610974289L, 678561108L, -32526229L, 
-174396179L, -1394445086L, 703102616L, 407146868L, -2078672036L, 
-1256457033L, 294791545L, 1051403850L, 1396252213L, 920609836L, 
--1238097601L, -270571078L, -885015652L, -1886896974L, -1111869269L, 
--1897073303L, 2060178631L, 309211348L, 737382455L, 381880273L, 
-406504622L, 322561947L, 418156606L, 826888637L, -945429503L, 
--209952944L, -441320544L, -1560528309L, -660161893L, 299996096L, 
--1703900038L, 938431591L, -558192135L, -1019549103L, -1672329068L, 
-1201372622L, 1450438703L, 402448730L, -2000724175L, -1014260896L, 
--1931428323L, -1308716858L, -248208943L, 835223455L, -1724511354L, 
--1257580837L, 2136338864L, -1141822223L, -1894714451L, -1132888420L, 
-1595688073L, -217493913L, -2115909373L, 1571707517L, 1591925212L, 
--1067871747L, -1018294891L, -896583058L, -391838768L, 302272755L, 
--390347203L, 1462647316L, 799891782L, -1790159337L, 748023879L, 
-159575618L, -1309899144L, -195330703L, 329722657L, -565598334L, 
--1722461179L, 270049812L, -710479260L, -337812810L, -1853869426L, 
--762990952L, 48262590L, -1197634419L, -1303096116L, 1803599878L, 
-954858014L, 726730240L, 1570516623L, -330294068L, 1577108601L, 
-1319064190L, 638519887L, 1246160781L, -2027933481L, 731496724L, 
-1730406235L, -1407870010L, 809914237L, -136033714L, 857559469L, 
--149520119L, -1777854207L, -843282854L, -871960071L, 659362552L, 
-718069151L, -611561423L, 338816492L, -1445995921L, -81531105L, 
--1073642119L, 1521151928L, -223675932L, 125033276L, 1667917047L, 
--402635858L, 482872989L, 1242891154L, 1942193217L, 79352565L, 
-1313524708L, 195978209L, 69741174L, -1312155576L, 765872807L, 
--1060639975L, -533469453L, 2130499504L, -1494163607L, -218197082L, 
--2102439294L, 626561515L, 241193531L, 222122984L, 849687351L, 
--1329956590L, -149014256L, -2015303586L, -1438748405L, 1737049072L, 
--132179160L, 1679630794L, -568284434L, 742353165L, 55375826L, 
--1078017852L, 421695022L, 1327889240L, -1503614507L, 32234643L, 
-1254483715L, -1329473632L, -575796063L, 358537051L, -855695797L, 
-824227879L, -1729821191L, 676503235L, -1409706927L, -1220816300L, 
-559566648L, -489043489L, -1323338543L, -1856725329L, 217616266L, 
--850464816L, 662035922L, -1971545537L, -638500449L, 1128223955L, 
-1841396459L, -619297234L, -1106369729L, 741406458L, -228964598L, 
--135692550L, -415150124L, -1092491375L, -1106316513L, -2041493043L, 
--743324990L, -640276354L, 893158712L, 79881785L, 259691653L, 
--518499215L, 91553569L, 1419048091L, 1379593679L, 490643031L, 
-137364535L, -187738073L, -1633295995L, 1778622138L, -938968491L, 
-2072700433L, 1587518503L, -247754371L, -885986378L, -1957271467L, 
--2054585046L, -144313342L, 127386173L, 690602433L, -2066938320L, 
-192407988L, -1227453816L, -1835739574L, -1446328530L, -446065297L, 
--1324295481L, 1808142298L, -1077131090L, 713312401L, 176894867L, 
--290246018L, -1919888873L, -323107480L, -779130222L, 75866497L, 
-315953862L, 1972384197L, -503475227L, -1054460128L, 1749915135L, 
-1195708349L, 702689467L, -811378646L, 1603266005L, -858288831L, 
--1217571003L, -1784903766L, 1355414720L, 591259547L, 742618990L, 
-769384466L, -1429600743L, -165588617L, 380149244L, -1214198694L, 
--558405688L, 505292793L, 1951467840L, -815008921L, 791717367L, 
-890280568L, 159585921L, -509101366L, 929706108L, -1022558099L, 
--1227474374L, -789023910L, -1927620187L, -1924537019L, -177451935L, 
--591206913L, -164748335L, -843739150L, -1569822239L, -118748707L, 
-649845678L, -823882596L, 1092164920L, 727633320L, -1672155090L, 
-830299776L, -798845332L, -1409655101L, -384003944L, 2113070897L, 
--1055740573L, -1116224766L, -149017416L, 914515614L, -1601120797L, 
--1175077960L, 635043640L, -1535600078L, 1478021893L, 1727886288L, 
-1671251412L, 1625661593L, -1269522504L, -117450764L, 1320982462L, 
-1055543110L, -2063554869L, -555638435L, -922472653L, 233721215L, 
--1029322078L, 799206482L, 799446426L, 782704024L, 1193356916L, 
-292113243L, 1617180488L, 2030814080L, -1114780640L, 1532617049L, 
-1231805611L, -1067442892L, -1356925211L, 1532362880L, 132521241L, 
--82812776L, -552336929L, 1495651968L, 2039728414L, 2126844121L, 
--985328359L, -1994947529L, -1038514567L, 1436843471L, 2114856360L, 
-1635515001L, 976586155L, -71203483L, 891545339L, -638692642L, 
-1430613133L, -378644142L, 290469753L, 1180768959L, -1685873244L, 
-353720976L, 1443297821L, -471222006L, 1134630668L, 321211584L, 
--1701219567L, 57954525L, -975674228L, 1042023524L, -209671509L, 
-1740538067L, -471220693L, 1170938953L, 296635809L, 1486193016L, 
-580866282L, 1932048863L, 228446328L, 1815508540L, -1879275707L, 
--2140354011L, 143924871L, -1986488283L, 589904000L, 1903750703L, 
--415443172L, 1859307430L, -1469176564L, 497566432L, -721627866L, 
-414959067L, 2119608405L, -2056242432L, 1748790347L, -1836524280L, 
--604319628L, 647673962L, -2055352872L, 1743204552L, 724809221L, 
-629724965L, 261337954L, -336291101L, 73908369L, -2006206083L, 
--1832558056L, 807246340L, -48863616L, -182367148L, 1212537756L, 
-1232486002L, -486827130L, 982651407L, -394299582L, 210724779L, 
-1305713339L, 1721807473L, -1635674346L, 1284179303L, 689688268L, 
--1473515637L, -1103667165L, 1232126541L, -174355958L, -163254679L, 
-897435999L, -1678310327L, -1504585109L, 1539585450L, 990684448L, 
--1498933867L, -1023184718L, -35646167L, 331792546L, 730166067L, 
-1805991271L, 1662342745L, 2058042350L, 1274100405L, -656110916L, 
-1939758265L, -690892225L, -1703892180L, 743388093L, -176795619L, 
-842862460L, -52841045L, 1464291695L, 993756365L, -1369750890L, 
--801310429L, -675370673L, -1538352917L, -808325592L, 1466383484L, 
-1826784035L, 829129643L, 1279779620L, 1077232139L, -740684867L, 
--844945669L, -703246794L, -474551677L, -148324544L, -1556251256L, 
--783700436L, -574946419L, 1225485881L, 1961374901L, -1118832472L, 
-125980600L, -259295769L, 730077669L, -1283473195L, 728194711L, 
--387044539L, 1689519239L, 250946503L, 190861505L, 1770075403L, 
--793651039L, 400586806L, 975298806L, 641814340L, 1127569593L, 
-1478152005L, -66220139L, 613576818L, 563083520L, -1759960774L, 
-1507455734L, 289932207L, -428167323L, 1242795809L, -1137320636L, 
-517604505L, 180344843L, 2127807329L, -1718531053L, -1038847805L, 
-310395024L, -1640526618L, 1264206939L, 393730669L, -1956611761L, 
-634560140L, -67253725L, 1155306924L, 1240896408L, -637557255L, 
-94923525L, -978754831L, 1275289986L, 291846590L, 1915055832L, 
-1163523235L, 822266910L, -481178691L, 1937010816L, 239405847L, 
-597445786L, 1758199875L, 1446620402L, 175169290L, 609673531L, 
-1884633281L, 938877300L, -641451098L, -1875308359L, -2110940784L, 
-1009133294L, -801629269L, 1306023320L, -496748005L, -1691788265L, 
-1961102437L, -1503120899L, 469906541L, 1806337495L, -384871920L, 
-163994338L, 1414772416L, 1077327799L, -969426492L, -914600642L, 
--706091035L, -1472608170L, 1933734468L, -382933522L, 1509038384L, 
--2145769488L, 1013192113L, -998078197L, -56609482L, -951495796L, 
--270028884L, -2135722482L, -557376975L, -1349815574L, -841130365L, 
--1833685961L, -1135178962L, 1805416481L, -1707325387L, -835233650L, 
--1775980440L, 1568787060L, 1590960471L, 365667936L, -1792969509L, 
-644149446L, 1258804967L, -539491416L, 551146069L, 117520920L, 
-706791561L, -623008986L, 392369787L, -1598319152L, 918051753L, 
-1457969483L, -51299690L, -296048864L, -1867524345L, 1994962544L, 
-666722704L, 397334122L, 417341718L, 937322299L, 1863174697L, 
--1698178314L, -1543228816L, 631929173L, -772382884L, -1672121366L, 
--638439291L, 1025633280L, 1136328884L, 1516095699L, 1095939602L, 
-693378375L, 579558920L, 905772869L, -774725317L, 1805573117L, 
-1236612744L, -2005094588L, -1711550111L, -391735297L, 651021245L, 
-829215356L, 264655358L, -2006715365L, 2107674005L, 1774128903L
-)
+c(403L, 10L, -1793453778L, -119326503L, -1173310741L, 968908634L, 
+78285084L, -895942625L, -1293554571L, 1991293196L, 1199740130L, 
+-610878019L, 1330571831L, 293525726L, -1914465256L, 2067180411L, 
+1785314073L, -1798346840L, 1134012246L, -240910383L, 1275648899L, 
+-424370670L, 1420491172L, 365387111L, -878861635L, -539401676L, 
+932469146L, 353404389L, -1879719553L, 1097345286L, -1102810480L, 
+1739068211L, -2117154607L, 1078045312L, -1021396130L, 307628201L, 
+1135856475L, 1201002858L, 338676748L, 1207364687L, -1432011515L, 
+1066024380L, -363587438L, 557955981L, -1056146489L, -1392729938L, 
+401109256L, 1396649739L, -801891863L, -469295432L, 1199999334L, 
+-1485747711L, -1086700397L, -1026711742L, -1628729100L, -756462345L, 
+490620141L, -2000341116L, 2144291242L, 1979674389L, 2093444527L, 
+734590390L, -1015387168L, 1276076835L, 641827905L, 1741952816L, 
+-321448626L, -357066823L, 1352913355L, 1424773754L, 572102524L, 
+-495986753L, 272375957L, -12767572L, 1225579650L, 809561181L, 
+1627829079L, 2045333054L, -56786312L, -10292901L, 1684086969L, 
+-907333368L, 1866286006L, -1723367183L, 2022897443L, 1023971698L, 
+-213179452L, -473149561L, -114248355L, 501508948L, 1245909370L, 
+-243393339L, -1914274273L, 406018470L, -459367632L, -528320045L, 
+1983512561L, 538134816L, -71075906L, -488859703L, 638302075L, 
+822537546L, 639240620L, -1675369297L, 605281893L, 1099253276L, 
+773101682L, -362389779L, 1089651495L, 1145757518L, -997959768L, 
+-2143394901L, -2105253687L, 505899224L, -199567994L, -823079839L, 
+-2131542541L, 189021282L, -848201004L, -867415081L, 2137948621L, 
+601757028L, 1487593802L, 872220853L, 285483023L, -109405930L, 
+204145600L, 905219971L, 1625963937L, -199597680L, -746214802L, 
+424676377L, 1537511595L, -867797862L, 1845167196L, 1387200863L, 
+1555669813L, 958555852L, 1091138594L, 2055456381L, 1296948087L, 
+1156568222L, -1172991144L, -1174661445L, -918439847L, -1619530776L, 
+-604361194L, 309784977L, 1252598339L, -154328750L, 751711716L, 
+190487591L, 1136978045L, 1783969140L, 73513306L, 1402646437L, 
+-782544961L, 192676934L, -1871633712L, -1638191885L, -1646556655L, 
+508873792L, 115171358L, -918716695L, 798276635L, 285987882L, 
+-973822132L, -88220401L, 1658847301L, 1572612604L, 1514874962L, 
+355717581L, 1792553863L, 614831726L, 42767944L, 792227915L, 378542505L, 
+273716472L, -1802641370L, -874041023L, 608947923L, -1449036158L, 
+1932393652L, -388709321L, 1714071341L, 336307268L, -504624790L, 
+1415914965L, 1343554415L, -764994954L, -565224032L, 1406782051L, 
+1086184193L, 522719856L, -1409593842L, -198179207L, 2078945803L, 
+1938467642L, 3592764L, 1395888511L, 1820211925L, 452958956L, 
+1273474114L, -1009532003L, 2056149527L, 731979646L, -1357009608L, 
+-265369061L, -1072295047L, -932796984L, 1421040118L, 1764805681L, 
+-297005469L, -1908436430L, 2138709892L, 1768418759L, 1242244253L, 
+-684645356L, 868975290L, 68403973L, -1461061409L, -1391713946L, 
+-1118935824L, 1373433875L, 476263857L, -382939040L, -715162114L, 
+-1131124343L, 78151355L, -1137507444L, 2140384700L, -1614046158L, 
+-2139723968L, 719422644L, 1021495112L, -1493906758L, -1204052208L, 
+508148972L, 576439380L, 496930578L, -1017202784L, -279686196L, 
+-937766048L, 201491650L, 943494696L, 1047729580L, 144657212L, 
+2115549042L, 639391536L, 1897657892L, -1327692744L, -249782054L, 
+772076944L, 448346876L, -1831668844L, -187451582L, -1872077312L, 
+-1159338436L, -2143524272L, -1572448606L, -1683184824L, -1234415092L, 
+-949045028L, 814774866L, -1442426752L, 793103188L, -480180760L, 
+-482640134L, -1481774256L, -351474644L, -181491340L, -1605159278L, 
+1751592544L, 818505356L, -1862133920L, -1699726622L, 967651496L, 
+1352645836L, 48914940L, -485736526L, 214395376L, -1908873788L, 
+546945880L, 1868312442L, 1376802224L, 1351357884L, -867957676L, 
+1359677378L, -1975154912L, -1824932932L, -583444912L, 1791412706L, 
+-902703768L, -810939060L, 786003196L, 1080662770L, -823278848L, 
+615730804L, 1740264456L, 1545263546L, 155087824L, 1011795436L, 
+-202461292L, 605683410L, -563860896L, -1913995956L, 260899104L, 
+1769651842L, 1417819624L, 1134121964L, 616602172L, 1146246770L, 
+-1413256336L, -431582940L, 975790648L, -711599718L, -685118000L, 
+88718780L, 728679572L, -1383135102L, -2027086400L, -1693024452L, 
+1102442640L, 1276341026L, -345957880L, -701437684L, 839072156L, 
+173099538L, -919986304L, 1164151572L, 1401049384L, 1541707834L, 
+-1787241520L, 1671827052L, 1825657396L, 1710139026L, -1814114976L, 
+-1910347444L, 771957728L, -1585851998L, -491038296L, -802449780L, 
+1763462588L, -1530273166L, -1917645840L, -1380273596L, 833228888L, 
+1610122298L, -2035157904L, 1996862524L, -960375532L, 739097282L, 
+405305056L, 444058748L, -2107188528L, 903104930L, 267967528L, 
+-1241000180L, -1486430788L, 1657100082L, 658923200L, 918093876L, 
+-1176928568L, 870484154L, -655494512L, 970923756L, -1301902764L, 
+1664044690L, -1584083680L, -879786548L, 48840416L, -474487614L, 
+1088969768L, -493427796L, -617386308L, 1670911986L, 1578592816L, 
+884442020L, -1347805768L, 675602266L, -50487152L, 238874492L, 
+-1429080812L, -488400574L, -1231506176L, -1629834820L, 236852560L, 
+-1319804638L, -590704056L, 906548236L, 2037240412L, 519968210L, 
+-1362014720L, -393938604L, 376437992L, 1753131258L, -1125561648L, 
+546488108L, -933833484L, 2032528786L, -116670112L, 431116300L, 
+-1314195232L, 1967228514L, -90349400L, -1433448372L, 1768499068L, 
+1281649970L, 1307602544L, 632194884L, 1096358872L, 1989846906L, 
+-2142723024L, -1884510276L, -1930474924L, 714483778L, 604534432L, 
+-2043776324L, -1367187504L, 878322018L, -1711461656L, -1486746420L, 
+215546364L, 803967474L, -736171904L, 256269812L, -301766008L, 
+1148421946L, -2141056688L, 1712304236L, 1923192212L, 1953784914L, 
+-2089029152L, -576855860L, 1803659936L, -1236440702L, 1981099240L, 
+1294840556L, -243996356L, -309451662L, 530099824L, 1412367908L, 
+-1350698952L, 863651098L, 1836867792L, 860806460L, -852082796L, 
+-442667134L, 2104328128L, -1540897220L, -1854670448L, 360092706L, 
+826128648L, -1641655156L, 1695425308L, 1645922450L, 599736454L, 
+322778308L, 969986549L, -2088629153L, -1935642952L, 2127511446L, 
+850261411L, -1504171675L, -606928766L, 2047961584L, -1462476903L, 
+-1291757173L, 1011352700L, -2114474326L, -716125985L, 1548246633L, 
+-2138370946L, 1439024236L, -854862659L, 319556999L, -2055624336L, 
+-863343602L, 40575291L, 1084091933L, -247483702L, -10347032L, 
+1822180049L, -1182155069L, 1565177284L, -1776483726L, 677575495L, 
+-291159279L, 1992478358L, -503790604L, -1401852539L, -1432821553L, 
+-937735736L, -1632229274L, 1511947923L, -1595167243L, 428191698L, 
+-1767420896L, 574516745L, 768464699L, -667968884L, -208109798L, 
+919949711L, 1098796761L, -1263537810L, 1779809532L, 1243117165L, 
+874480151L, 1655109600L, 310080446L, -85978741L, 2012013069L, 
+-1309401542L, -345565576L, -114393567L, -1269092141L, 1339207668L, 
+-1241208702L, -156647145L, -1700595743L, 2008949030L, 2051883044L, 
+-1353424171L, -1464512897L, -1137950952L, 448130614L, -1453776701L, 
+496213253L, -1233623902L, -1832428912L, -669047239L, -1905477909L, 
+931227612L, 1121757706L, -885834497L, 568883529L, -499815714L, 
+1685166220L, -792137635L, -1949008281L, 216739728L, 830137262L, 
+496241243L, -696089027L, -1427343190L, 1724041544L, 1238433137L, 
+-708887837L, 808964580L, 516889874L, -199618329L, -1145346383L, 
+1530666230L, 907083540L, -1742006235L, -364634833L, -1417596184L, 
+1635897286L, -670403981L, -1025608491L, -1395861838L, 952602240L, 
+-523110807L, -1667622181L, 1207625260L, 1740400186L, 853565679L, 
+-1233228935L, 1366059022L, 633753052L, 557219405L, -509223497L, 
+968897344L, 1937736222L, -381057813L, -1828664211L, -1192399654L, 
+-1711917928L, -1027951871L, 1109547187L, -810863660L, -538775838L, 
+-1586843785L, 479408833L, 410403398L, -538448508L, -2066509003L, 
+728584479L, -1852262280L, -586701482L, -1714365469L, -3050075L, 
+-446867390L, -950397392L, -335958439L, -926980149L, 1209530428L, 
+1868957290L, 1084628127L, 395865385L, 332077502L, -1328170836L, 
+-866607619L, 1513309511L, -77251024L, -2093029554L, -833807493L, 
+-2132296483L, -2020487926L, -1520207832L, 193465489L, -607487869L, 
+177420676L, 1746651058L, 2031913223L, -1491473583L, -1315480874L, 
+1378198452L, -817538107L, -1274348785L, 1857849736L, 1705151654L, 
+-1410139053L, -1668137547L, -959859950L, -2099520413L)
 .txtline <-
 function(txt, width, space="", ind="") {
   paste(
@@ -1007,5 +1085,6 @@ function( wrd, main="Bericht" ){
   wrdView[["SeekView"]] <- wdConst$wdSeekMainDocument
   
   wrd[["Selection"]]$InsertBreak( wdConst$wdPageBreak)
+  invisible()
   
 }
