@@ -4,7 +4,7 @@ function( visible = TRUE ) {
   stopifnot(require(RDCOMClient))
   
   # Starts the Excel with xl as handle
-  xl <- COMCreate("Excel.Application")
+  xl <- RDCOMClient::COMCreate("Excel.Application")
   if( visible == TRUE ) xl[["Visible"]] <- TRUE
   
   # Create a new workbook
