@@ -1,6 +1,6 @@
 PlotViolin.formula <-
-function (formula, data = NULL, ..., subset) 
-{
+function (formula, data = NULL, ..., subset) {
+  
     if (missing(formula) || (length(formula) != 3)) 
         stop("formula missing or incorrect")
     m <- match.call(expand.dots = FALSE)
